@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,15 +19,18 @@ from typing import Dict, Type
 from .base import CloudBuildTransport
 from .grpc import CloudBuildGrpcTransport
 from .grpc_asyncio import CloudBuildGrpcAsyncIOTransport
-
+from .rest import CloudBuildRestInterceptor, CloudBuildRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[CloudBuildTransport]]
 _transport_registry["grpc"] = CloudBuildGrpcTransport
 _transport_registry["grpc_asyncio"] = CloudBuildGrpcAsyncIOTransport
+_transport_registry["rest"] = CloudBuildRestTransport
 
 __all__ = (
     "CloudBuildTransport",
     "CloudBuildGrpcTransport",
     "CloudBuildGrpcAsyncIOTransport",
+    "CloudBuildRestTransport",
+    "CloudBuildRestInterceptor",
 )
