@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,22 +13,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers_async
-from google.api_core import operations_v1
+from google.api_core import gapic_v1, grpc_helpers_async, operations_v1
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
 from google.cloud.devtools.cloudbuild_v1.types import cloudbuild
-from google.longrunning import operations_pb2  # type: ignore
-from google.protobuf import empty_pb2  # type: ignore
-from .base import CloudBuildTransport, DEFAULT_CLIENT_INFO
+
+from .base import DEFAULT_CLIENT_INFO, CloudBuildTransport
 from .grpc import CloudBuildGrpcTransport
 
 
@@ -328,6 +326,7 @@ class CloudBuildGrpcAsyncIOTransport(CloudBuildTransport):
         r"""Return a callable for the list builds method over gRPC.
 
         Lists previously requested builds.
+
         Previously requested builds may still be in-progress, or
         may have finished successfully or unsuccessfully.
 
@@ -402,7 +401,7 @@ class CloudBuildGrpcAsyncIOTransport(CloudBuildTransport):
 
         For builds that specify ``StorageSource``:
 
-        -  If the original build pulled source from Google Cloud Storage
+        -  If the original build pulled source from Cloud Storage
            without specifying the generation of the object, the new
            build will use the current object, which may be different
            from the original build source.
@@ -439,6 +438,7 @@ class CloudBuildGrpcAsyncIOTransport(CloudBuildTransport):
         r"""Return a callable for the approve build method over gRPC.
 
         Approves or rejects a pending build.
+
         If approved, the returned LRO will be analogous to the
         LRO returned from a CreateBuild call.
 
@@ -621,6 +621,12 @@ class CloudBuildGrpcAsyncIOTransport(CloudBuildTransport):
 
         Runs a ``BuildTrigger`` at a particular source revision.
 
+        To run a regional or global trigger, use the POST request that
+        includes the location endpoint in the path (ex.
+        v1/projects/{projectId}/locations/{region}/triggers/{triggerId}:run).
+        The POST request that does not include the location endpoint in
+        the path can only be used when running global triggers.
+
         Returns:
             Callable[[~.RunBuildTriggerRequest],
                     Awaitable[~.Operation]]:
