@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,32 +13,29 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers_async
-from google.api_core import operations_v1
+from google.api_core import gapic_v1, grpc_helpers_async, operations_v1
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.cloud.location import locations_pb2  # type: ignore
+from google.iam.v1 import iam_policy_pb2  # type: ignore
+from google.iam.v1 import policy_pb2  # type: ignore
+from google.longrunning import operations_pb2  # type: ignore
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
 from google.cloud.devtools.cloudbuild_v2.types import repositories
-from google.cloud.location import locations_pb2  # type: ignore
-from google.iam.v1 import iam_policy_pb2  # type: ignore
-from google.iam.v1 import policy_pb2  # type: ignore
-from google.longrunning import operations_pb2
-from google.longrunning import operations_pb2  # type: ignore
-from .base import RepositoryManagerTransport, DEFAULT_CLIENT_INFO
+
+from .base import DEFAULT_CLIENT_INFO, RepositoryManagerTransport
 from .grpc import RepositoryManagerGrpcTransport
 
 
 class RepositoryManagerGrpcAsyncIOTransport(RepositoryManagerTransport):
     """gRPC AsyncIO backend transport for RepositoryManager.
 
-    Manages connections to source code repostiories.
+    Manages connections to source code repositories.
 
     This class defines the same methods as the primary client, so the
     primary client can load the underlying transport implementation
@@ -627,6 +624,35 @@ class RepositoryManagerGrpcAsyncIOTransport(RepositoryManagerTransport):
             )
         return self._stubs["fetch_linkable_repositories"]
 
+    @property
+    def fetch_git_refs(
+        self,
+    ) -> Callable[
+        [repositories.FetchGitRefsRequest], Awaitable[repositories.FetchGitRefsResponse]
+    ]:
+        r"""Return a callable for the fetch git refs method over gRPC.
+
+        Fetch the list of branches or tags for a given
+        repository.
+
+        Returns:
+            Callable[[~.FetchGitRefsRequest],
+                    Awaitable[~.FetchGitRefsResponse]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "fetch_git_refs" not in self._stubs:
+            self._stubs["fetch_git_refs"] = self.grpc_channel.unary_unary(
+                "/google.devtools.cloudbuild.v2.RepositoryManager/FetchGitRefs",
+                request_serializer=repositories.FetchGitRefsRequest.serialize,
+                response_deserializer=repositories.FetchGitRefsResponse.deserialize,
+            )
+        return self._stubs["fetch_git_refs"]
+
     def close(self):
         return self.grpc_channel.close()
 
