@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,11 +17,10 @@ from __future__ import annotations
 
 from typing import MutableMapping, MutableSequence
 
-import proto  # type: ignore
-
+from google.api import httpbody_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.devtools.cloudbuild.v2",
@@ -32,9 +31,11 @@ __protobuf__ = proto.module(
         "FetchLinkableRepositoriesResponse",
         "GitHubConfig",
         "GitHubEnterpriseConfig",
+        "GitLabConfig",
         "ServiceDirectoryConfig",
         "Repository",
         "OAuthCredential",
+        "UserCredential",
         "CreateConnectionRequest",
         "GetConnectionRequest",
         "ListConnectionsRequest",
@@ -52,6 +53,9 @@ __protobuf__ = proto.module(
         "FetchReadTokenRequest",
         "FetchReadTokenResponse",
         "FetchReadWriteTokenResponse",
+        "ProcessWebhookRequest",
+        "FetchGitRefsRequest",
+        "FetchGitRefsResponse",
     },
 )
 
@@ -86,6 +90,11 @@ class Connection(proto.Message):
             Configuration for connections to an instance
             of GitHub Enterprise.
 
+            This field is a member of `oneof`_ ``connection_config``.
+        gitlab_config (google.cloud.devtools.cloudbuild_v2.types.GitLabConfig):
+            Configuration for connections to gitlab.com
+            or an instance of GitLab Enterprise.
+
             This field is a member of `oneof`_ ``connection_config``.
         installation_state (google.cloud.devtools.cloudbuild_v2.types.InstallationState):
             Output only. Installation state of the
@@ -135,6 +144,12 @@ class Connection(proto.Message):
         oneof="connection_config",
         message="GitHubEnterpriseConfig",
     )
+    gitlab_config: "GitLabConfig" = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        oneof="connection_config",
+        message="GitLabConfig",
+    )
     installation_state: "InstallationState" = proto.Field(
         proto.MESSAGE,
         number=12,
@@ -382,6 +397,74 @@ class GitHubEnterpriseConfig(proto.Message):
     )
 
 
+class GitLabConfig(proto.Message):
+    r"""Configuration for connections to gitlab.com or an instance of
+    GitLab Enterprise.
+
+    Attributes:
+        host_uri (str):
+            The URI of the GitLab Enterprise host this
+            connection is for. If not specified, the default
+            value is https://gitlab.com.
+        webhook_secret_secret_version (str):
+            Required. Immutable. SecretManager resource containing the
+            webhook secret of a GitLab Enterprise project, formatted as
+            ``projects/*/secrets/*/versions/*``.
+        read_authorizer_credential (google.cloud.devtools.cloudbuild_v2.types.UserCredential):
+            Required. A GitLab personal access token with the minimum
+            ``read_api`` scope access.
+        authorizer_credential (google.cloud.devtools.cloudbuild_v2.types.UserCredential):
+            Required. A GitLab personal access token with the ``api``
+            scope access.
+        service_directory_config (google.cloud.devtools.cloudbuild_v2.types.ServiceDirectoryConfig):
+            Configuration for using Service Directory to
+            privately connect to a GitLab Enterprise server.
+            This should only be set if the GitLab Enterprise
+            server is hosted on-premises and not reachable
+            by public internet. If this field is left empty,
+            calls to the GitLab Enterprise server will be
+            made over the public internet.
+        ssl_ca (str):
+            SSL certificate to use for requests to GitLab
+            Enterprise.
+        server_version (str):
+            Output only. Version of the GitLab Enterprise server running
+            on the ``host_uri``.
+    """
+
+    host_uri: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    webhook_secret_secret_version: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    read_authorizer_credential: "UserCredential" = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="UserCredential",
+    )
+    authorizer_credential: "UserCredential" = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="UserCredential",
+    )
+    service_directory_config: "ServiceDirectoryConfig" = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message="ServiceDirectoryConfig",
+    )
+    ssl_ca: str = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    server_version: str = proto.Field(
+        proto.STRING,
+        number=7,
+    )
+
+
 class ServiceDirectoryConfig(proto.Message):
     r"""ServiceDirectoryConfig represents Service Directory
     configuration for a connection.
@@ -390,6 +473,7 @@ class ServiceDirectoryConfig(proto.Message):
         service (str):
             Required. The Service Directory service name.
             Format:
+
             projects/{project}/locations/{location}/namespaces/{namespace}/services/{service}.
     """
 
@@ -422,6 +506,9 @@ class Repository(proto.Message):
             on the value of other fields, and may be sent on
             update and delete requests to ensure the client
             has an up-to-date value before proceeding.
+        webhook_id (str):
+            Output only. External ID of the webhook
+            created for the repository.
     """
 
     name: str = proto.Field(
@@ -451,6 +538,10 @@ class Repository(proto.Message):
         proto.STRING,
         number=7,
     )
+    webhook_id: str = proto.Field(
+        proto.STRING,
+        number=8,
+    )
 
 
 class OAuthCredential(proto.Message):
@@ -477,6 +568,30 @@ class OAuthCredential(proto.Message):
     )
 
 
+class UserCredential(proto.Message):
+    r"""Represents a personal access token that authorized the
+    Connection, and associated metadata.
+
+    Attributes:
+        user_token_secret_version (str):
+            Required. A SecretManager resource containing the user token
+            that authorizes the Cloud Build connection. Format:
+            ``projects/*/secrets/*/versions/*``.
+        username (str):
+            Output only. The username associated to this
+            token.
+    """
+
+    user_token_secret_version: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    username: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+
+
 class CreateConnectionRequest(proto.Message):
     r"""Message for creating a Connection
 
@@ -907,4 +1022,84 @@ class FetchReadWriteTokenResponse(proto.Message):
     )
 
 
+class ProcessWebhookRequest(proto.Message):
+    r"""RPC request object accepted by the ProcessWebhook RPC method.
+
+    Attributes:
+        parent (str):
+            Required. Project and location where the webhook will be
+            received. Format: ``projects/*/locations/*``.
+        body (google.api.httpbody_pb2.HttpBody):
+            HTTP request body.
+        webhook_key (str):
+            Arbitrary additional key to find the maching
+            repository for a webhook event if needed.
+    """
+
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    body: httpbody_pb2.HttpBody = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=httpbody_pb2.HttpBody,
+    )
+    webhook_key: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+
+
+class FetchGitRefsRequest(proto.Message):
+    r"""Request for fetching git refs
+
+    Attributes:
+        repository (str):
+            Required. The resource name of the repository in the format
+            ``projects/*/locations/*/connections/*/repositories/*``.
+        ref_type (google.cloud.devtools.cloudbuild_v2.types.FetchGitRefsRequest.RefType):
+            Type of refs to fetch
+    """
+
+    class RefType(proto.Enum):
+        r"""Type of refs
+
+        Values:
+            REF_TYPE_UNSPECIFIED (0):
+                No type specified.
+            TAG (1):
+                To fetch tags.
+            BRANCH (2):
+                To fetch branches.
+        """
+        REF_TYPE_UNSPECIFIED = 0
+        TAG = 1
+        BRANCH = 2
+
+    repository: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    ref_type: RefType = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=RefType,
+    )
+
+
+class FetchGitRefsResponse(proto.Message):
+    r"""Response for fetching git refs
+
+    Attributes:
+        ref_names (MutableSequence[str]):
+            Name of the refs fetched.
+    """
+
+    ref_names: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
+
+
 __all__ = tuple(sorted(__protobuf__.manifest))
